<?php
require_once '../include/utils.php';
require_once '../include/artwork_images.php';
require_once '../include/comments.php';
require_once '../include/artworks_grid.php';

if (!isset($_GET['id']) || !ctype_digit($_GET['id'])) {
	die_with_message(
		get_string('error'),
		get_string('artworks.illegal-request')
	);
}

$id = $_GET['id'];
$artwork = json_decode(
	get(sprintf(ARTWORK_INFO_URL, $id))
)->body;

if (!$artwork) {
	die_with_message(
		get_string('error'),
		get_string('artworks.not-found')
	);
}

if (artwork_is_hidden($artwork, $type)) {
	die_with_message(
		get_string('error'),
		get_string('artworks.hidden-' . $type)
	);
}

render_page_header(htmlspecialchars($artwork->title));
?>

<div class="container">
	<?php render_artwork_images($artwork) ?>

	<h1><?= htmlspecialchars($artwork->title) ?></h1>

	<p><?= $artwork->description ?></p>

	<p><div class="tags"><?php
		if ($artwork->xRestrict == 1) { ?>
			<div>
				<b><a class="highlight" href="<?= BASE_URL ?>/tags/R-18"><?= get_string('artworks.r18') ?></a></b>
			</div><?php
		}
		else if ($artwork->xRestrict == 2) { ?>
			<div>
				<b><a class="highlight" href="<?= BASE_URL ?>/tags/R-18G"><?= get_string('artworks.r18g') ?></a></b>
			</div><?php
		}
		if ($artwork->aiType == 2) { ?>
			<div>
				<b><a href="<?= BASE_URL ?>/tags/AI-generated"><?= get_string('artworks.aigc') ?></a></b>
			</div><?php
		}
		foreach ($artwork->tags->tags as $tag) {
			if($tag->tag == 'R-18' || $tag->tag == 'R-18G') continue;
			$tag_ja = htmlspecialchars($tag->tag);
			$tag_translated = htmlspecialchars(
				isset($tag->translation->en) ? $tag->translation->en
				: (isset($tag->romaji) ? $tag->romaji : '')
			); ?>
			<div>
				<a href="<?= BASE_URL ?>/tags/<?= $tag_ja ?>">#<?= $tag_ja ?></a>
				<small><?= $tag_translated ?></small>
			</div><?php
		} ?>
	</div></p>

	<p><div class="stats">
		<div><?= sprintf(get_string('artworks.likes'), $artwork->likeCount) ?></div>
		<div><?= sprintf(get_string('artworks.bookmarks'), $artwork->bookmarkCount) ?></div>
		<div><?= sprintf(get_string('artworks.views'), $artwork->viewCount) ?></div>
	</div></p>

	<p><?= gmdate(get_string('date-format'), strtotime($artwork->createDate)); ?>

	<?php
	$pfp_url = '';
	foreach ($artwork->userIllusts as $v) {
		if (isset($v->profileImageUrl)) {
			$pfp_url = get_proxy_url($v->profileImageUrl);
		}
	}
	?>

	<p><a class="img-with-text" href="<?= BASE_URL ?>/users/<?= $artwork->userId ?>">
		<img class="avatar" src="<?= $pfp_url ?>">
		<span><?= htmlspecialchars($artwork->userName) ?></span>
	</a></p>

	<hr>

	<h2><?= sprintf(get_string('artworks.comments'), $artwork->commentCount) ?></h2>
	<?php
	if ($artwork->commentCount == 0) { ?>
		<p><?= get_string('artworks.no-comments') ?></p><?php
	}
	else {
		$comments = json_decode(
			get(sprintf(ARTWORK_COMMENTS_URL, $id, COMMENTS_LIMIT))
		)->body->comments;
		render_comment_list($comments);
	}
	?>
</div>

<div class="container container-big">
	<hr>
	<h2><?= get_string('artworks.related') ?></h2>
	<?php
	$related = json_decode(
		get(sprintf(ARTWORK_RELATED_URL, $id, 120))
	)->body->illusts;
	render_artworks_grid($related);
	?>
</div>

<?php
render_page_footer();
