<?php
const ARTWORKS_PER_PAGE = 24;

function render_artworks_grid($artworks_uncensored, $collapsed = true) {
    $artworks = [];
    foreach ($artworks_uncensored as $artwork) {
		if (!artwork_is_hidden($artwork)) array_push($artworks, $artwork);
	}

	if (!$artworks) {
		if ($artworks_uncensored) { ?>
			<p><?= get_string('all-hidden') ?></p><?php
		}
		else { ?>
			<p><?= get_string('no-works') ?></p><?php
		}
		return;
	}

	$page_count = $collapsed ? ceil(count($artworks) / ARTWORKS_PER_PAGE) : 1;
	render_collapsed_content($page_count, get_string('load-more'), function($page) use ($artworks, $collapsed) {
		$artworks_in_page = $collapsed ? array_slice($artworks, $page * ARTWORKS_PER_PAGE, ARTWORKS_PER_PAGE) : $artworks; ?>
		<div class="grid">
			<?php foreach ($artworks_in_page as $artwork) { ?>
				<a href="<?= BASE_URL ?>/artworks/<?= $artwork->id ?>">
					<div class="extra-info"><?php
						if ($artwork->xRestrict != 0) { ?>
							<div class="content-warning"><?= [1 => 'R-18', 2 => 'R-18G'][$artwork->xRestrict] ?></div><?php
						}
						if ($artwork->pageCount > 1) { ?>
							<div class="page-count">🗍 <?= $artwork->pageCount ?></div><?php
						} ?>
					</div>
					<img loading="lazy" src="<?= get_proxy_url($artwork->url) ?>" alt="<?= htmlspecialchars($artwork->alt); ?>">
					<div><?= htmlspecialchars($artwork->title); ?></div>
				</a>
			<?php } ?>
		</div><?php
	});
}
