<?php
const COMMENTS_FIRST_PAGE = 5;
const COMMENTS_PER_PAGE = 20;
const COMMENTS_LIMIT = 100;

const EMOJI_IDS = [
	'normal' => '101',
	'surprise' => '102',
	'serious' => '103',
	'heaven' => '104',
	'happy' => '105',
	'excited' => '106',
	'sing' => '107',
	'cry' => '108',
	'normal2' => '201',
	'shame2' => '202',
	'love2' => '203',
	'interesting2' => '204',
	'blush2' => '205',
	'fire2' => '206',
	'angry2' => '207',
	'shine2' => '208',
	'panic2' => '209',
	'normal3' => '301',
	'satisfaction3' => '302',
	'surprise3' => '303',
	'smile3' => '304',
	'shock3' => '305',
	'gaze3' => '306',
	'wink3' => '307',
	'happy3' => '308',
	'excited3' => '309',
	'love3' => '310',
	'normal4' => '401',
	'surprise4' => '402',
	'serious4' => '403',
	'love4' => '404',
	'shine4' => '405',
	'sweat4' => '406',
	'shame4' => '407',
	'sleep4' => '408',
	'heart' => '501',
	'teardrop' => '502',
	'star' => '503'
];

function parse_comment($comment) {
	return preg_replace_callback('/\((.+?)\)/', function($matches) {
		if (isset(EMOJI_IDS[$matches[1]])) {
			$emoji_url = get_proxy_url('https://s.pximg.net/common/images/emoji/' . EMOJI_IDS[$matches[1]] . '.png');
			return "<img class='emoji' src='{$emoji_url}'>";
		}
		else return $matches[0];
	}, $comment);
}

function render_comment_list($comments) {
	if (!$comments) { ?>
		<p><?= get_string('artworks.comments-failed') ?></p><?php
		return;
	}
	$page_count = ceil((count($comments) - COMMENTS_FIRST_PAGE)/ COMMENTS_PER_PAGE) + 1;
	render_collapsed_content($page_count, get_string('artworks.comments-show-more'), function($page) use ($comments) {
		$comments_in_page = array_slice(
			$comments,
			$page == 0 ? 0 : ($page - 1) * COMMENTS_PER_PAGE + COMMENTS_FIRST_PAGE,
			$page == 0 ? COMMENTS_FIRST_PAGE : COMMENTS_PER_PAGE
		);
		foreach ($comments_in_page as $comment) { ?>
			<div class="comment">
				<div class="comment-left">
					<a href="<?= BASE_URL ?>/users/<?= $comment->commentUserId ?>">
						<img class="avatar" src="<?= get_proxy_url($comment->img) ?>">
					</a>
				</div>
				<div class="comment-right">
					<div class="comment-info">
						<a href="<?= BASE_URL ?>/users/<?= $comment->commentUserId ?>"><?= htmlspecialchars($comment->userName) ?></a>
						<small><?= $comment->commentDate ?></small>
					</div>
					<p class="comment-content"><?php
						if ($comment->comment) {
							echo parse_comment($comment->comment);
						}
						else {
							$stamp_url = get_proxy_url('https://s.pximg.net/common/images/stamp/generated-stamps/' . $comment->stampId . '_s.jpg');
							echo "<img class='stamp' src='{$stamp_url}'>";
						} ?>
					</p>
				</div>
			</div><?php
		}
	});
}
