<?php
require_once '../include/utils.php';
require_once '../include/artworks_grid.php';
require_once '../include/paginator.php';

if (!isset($_GET['id']) || !ctype_digit($_GET['id'])) {
	die_with_message(
		get_string('error'),
		get_string('users.illegal-request')
	);
}

if (
	!isset($_GET['category'])
	|| !in_array($_GET['category'], ['artworks', 'illustrations', 'manga', 'bookmarks'])) {
	$_GET['category'] = 'artworks';
}

$id = $_GET['id'];
$user_info = json_decode(
	get(sprintf(USER_INFO_URL, $id))
)->body;

if (!$user_info) {
	die_with_message(
		get_string('error'),
		get_string('users.not-found')
	);
}

$username = htmlspecialchars($user_info->name);
$pathname = BASE_URL . '/users/' . $id;

render_page_header($username);
?>

<div class="container">
	<h1 class="img-with-text">
		<img class="avatar" src="<?= get_proxy_url($user_info->imageBig) ?>">
		<span><?= $username ?></span>
	</h1>

	<p><?= str_replace(PHP_EOL, "<br>", htmlspecialchars($user_info->comment)); ?></p>

	<div class="category-selector">
		<a class="<?php if($_GET['category'] == 'artworks') echo 'selected'; ?>"
			href="<?= $pathname ?>/artworks#artworks"><?= get_string('users.all') ?></a>
		<a class="<?php if($_GET['category'] == 'illustrations') echo 'selected'; ?>"
			href="<?= $pathname ?>/illustrations#artworks"><?= get_string('users.illusts') ?></a>
		<a class="<?php if($_GET['category'] == 'manga') echo 'selected'; ?>"
			href="<?= $pathname ?>/manga#artworks"><?= get_string('users.manga') ?></a>
		<a class="<?php if($_GET['category'] == 'bookmarks') echo 'selected'; ?>"
			href="<?= $pathname ?>/bookmarks#artworks"><?= get_string('users.bookmarks') ?></a>
	</div>

	<?php
	if($_GET['category'] == 'bookmarks') {
		$current_page = (isset($_GET['p']) && ctype_digit($_GET['p']) && $_GET['p'] > 0) ? $_GET['p'] : 1;
		$bookmarks = json_decode(
			get(sprintf(USER_BOOKMARKS_URL, $id, ARTWORKS_PER_PAGE * ($current_page - 1), ARTWORKS_PER_PAGE))
		)->body;
		$page_count = ceil($bookmarks->total / ARTWORKS_PER_PAGE);
		?>
		<h2 id="artworks"><?= sprintf(get_string('users.work-count'), $bookmarks->total) ?></h2>
		<?php
		render_artworks_grid($bookmarks->works);

		render_paginator($page_count, $current_page, function($page) use ($id) {
			return BASE_URL . '/users/' . $id . '/bookmarks?p=' . $page . '#artworks';
		});
	}
	else {
		$artworks = json_decode(
			get(sprintf(USER_ARTWORKS_URL, $id))
		, true)['body'];

		$artwork_ids = [];
		if ($_GET['category'] == 'artworks' || $_GET['category'] == 'illustrations') {
			$artwork_ids = array_merge(array_keys($artworks['illusts']), $artwork_ids);
		}
		if ($_GET['category'] == 'artworks' || $_GET['category'] == 'manga') {
			$artwork_ids = array_merge(array_keys($artworks['manga']), $artwork_ids);
		}
		rsort($artwork_ids);
		$artwork_count = count($artwork_ids);
		?>
		<h2 id="artworks"><?= sprintf(get_string('users.work-count'), $artwork_count) ?></h2>
		<?php
		if($artwork_ids) {
			$page_count = ceil($artwork_count / ARTWORKS_PER_PAGE);
			$current_page = (
				isset($_GET['p']) && ctype_digit($_GET['p']) && $_GET['p'] > 0 && $_GET['p'] <= $page_count
			) ? $_GET['p'] : 1;
			$artwork_ids_in_page = array_slice($artwork_ids, ($current_page - 1) * ARTWORKS_PER_PAGE, ARTWORKS_PER_PAGE);

			$artworks_in_page = json_decode(
				get(sprintf(USER_ARTWORKS_INFO_URL, $id, http_build_query(['ids' => $artwork_ids_in_page])))
			)->body->works;
			render_artworks_grid($artworks_in_page, false);

			render_paginator($page_count, $current_page, function($page) use ($id) {
				return BASE_URL . '/users/' . $id . '/' . $_GET['category'] . '?p=' . $page . '#artworks';
			});
		}
		else { ?>
			<p><?= get_string('no-works') ?></p><?php
		}
	} ?>
</div>

<?php
render_page_footer();
